@@ -21,14 +21,14 @@
 #include "vocabsettings.h"
 
 #include <KConfigDialog>
-#include <KNS3/DownloadDialog>
-
+#include <KNSWidgets/Button>
 #include <sharedkvtmlfiles.h>
 
 #include <QIcon>
 #include <QFileInfo>
 #include <QPointer>
 
+
 #include "kanagramsettings.h"
 #include "vocabedit.h"
 
@@ -38,8 +38,15 @@ VocabSettings::VocabSettings(QWidget *parent)
     setupUi(this);
 
     connect(lviewVocab, &QTreeWidget::currentItemChanged, this, &VocabSettings::slotSelectionChanged);
+    connect(KanagramSettings::self(), &KCoreConfigSkeleton::configChanged,
+            this, &VocabSettings::refreshView);
 
-    btnDownloadNew->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
+    connect(btnDownloadNew, &KNSWidgets::Button::dialogFinished, this, [this] (const QList<KNSCore::Entry> &changedEntries) {
+        if (!changedEntries.isEmpty()) {
+            refreshView();
+        }
+    });
+    btnDownloadNew->setConfigFile("kanagram.knsrc");
 
     refreshView();
 }
@@ -65,12 +72,14 @@ void VocabSettings::loadView()
         item->setText( 1, m_commentList[i] );
         m_itemMap[item] = i;
     }
+
+    lviewVocab->resizeColumnToContents(0);
 }
 
 void VocabSettings::refreshView()
 {
     loadView();
-    emit widgetModified();
+    Q_EMIT widgetModified();
 }
 
 void VocabSettings::on_btnEdit_clicked()
@@ -91,17 +100,6 @@ void VocabSettings::on_btnCreateNew_clicked()
     vocabEdit->show();
 }
 
-void VocabSettings::on_btnDownloadNew_clicked()
-{
-    QPointer<KNS3::DownloadDialog> dialog = new KNS3::DownloadDialog( QStringLiteral("kanagram.knsrc") );
-    dialog->exec();
-    if ( dialog->changedEntries().size() > 0 ){
-        refreshView();
-    }
-
-    delete dialog;
-}
-
 void VocabSettings::slotSelectionChanged(QTreeWidgetItem *item)
 {
     int index = m_itemMap.value(item);
